#ifndef NT2_INCLUDE_CONSTANTS_SQRTI_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_SQRTI_HPP_INCLUDED

#include <nt2/complex/include/constants/sqrti.hpp>

#endif
